@@ -23,10 +23,6 @@
 #include <config.h>
 #include <gmodule.h>
 
-#ifdef HAVE_GTK_SOURCEVIEW
-#include <gtksourceview/gtksource.h>
-#endif
-
 #include "playlist-treeview.h"
 #include "renderer-combo.h"
 #include "renderer-controls.h"
@@ -34,6 +30,8 @@
 #include "pretty-print.h"
 #include "gui.h"
 #include "server-device.h"
+#include "search-dialog.h"
+#include "didl-dialog.h"
 
 #define CONTENT_DIR "urn:schemas-upnp-org:service:ContentDirectory"
 
@@ -51,9 +49,9 @@ typedef gboolean (* RowCompareFunc) (GtkTreeModel *model,
 static GtkWidget *treeview;
 static GtkWidget *popup;
 static GtkWidget *didl_dialog;
-static GtkWidget *didl_textview;
 static gboolean   expanded;
 static GHashTable *initial_notify;
+static GtkDialog *search_dialog;
 
 gboolean
 on_playlist_treeview_button_release (GtkWidget      *widget,
@@ -78,6 +76,10 @@ void
 on_didl_menuitem_activate (GtkMenuItem *menuitem,
                            gpointer     user_data);
 
+void
+on_search_menu_item_activated (GtkMenuItem *menuitem,
+                               gpointer     user_data);
+
 gboolean
 on_playlist_treeview_popup_menu (GtkWidget *widget, gpointer user_data);
 
@@ -306,18 +308,9 @@ on_playlist_row_collapsed (GtkTreeView *tree_view,
 static void display_metadata (const char *metadata,
                               gpointer    user_data)
 {
-        GtkTextBuffer *buffer;
-        char *formatted;
-
-        formatted = pretty_print_xml (metadata);
-
-        buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (didl_textview));
-        gtk_text_buffer_set_text (buffer, formatted, -1);
-        gtk_widget_show (GTK_WIDGET (didl_textview));
+        av_cp_didl_dialog_set_xml (AV_CP_DIDL_DIALOG (didl_dialog), metadata);
 
         gtk_dialog_run (GTK_DIALOG (didl_dialog));
-
-        g_free (formatted);
 }
 
 G_MODULE_EXPORT
@@ -328,6 +321,43 @@ on_didl_menuitem_activate (GtkMenuItem *menuitem,
         get_selected_object (display_metadata, NULL);
 }
 
+G_MODULE_EXPORT
+void
+on_search_menu_item_activated (GtkMenuItem *menuitem,
+                               gpointer     user_data)
+{
+    AVCPMediaServer   *server;
+    GtkTreeSelection  *selection;
+    GtkTreeModel      *model;
+    GtkTreeIter        iter;
+    char              *id = NULL;
+    char              *title = NULL;
+
+    selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
+    g_assert (selection != NULL);
+
+    if (!gtk_tree_selection_get_selected (selection, &model, &iter)) {
+        return;
+    }
+
+    gtk_tree_model_get (model,
+                        &iter,
+                        1, &title,
+                        2, &server,
+                        4, &id,
+                        -1);
+
+    if (search_dialog == NULL) {
+        search_dialog = GTK_DIALOG (g_object_new (SEARCH_DIALOG_TYPE, NULL));
+    }
+
+    search_dialog_set_server (SEARCH_DIALOG (search_dialog), server);
+    search_dialog_set_container_id (SEARCH_DIALOG (search_dialog), id);
+    search_dialog_set_container_title (SEARCH_DIALOG (search_dialog), title);
+
+    search_dialog_run (SEARCH_DIALOG (search_dialog));
+}
+
 void
 setup_playlist_treeview (GtkBuilder *builder)
 {
@@ -343,33 +373,9 @@ setup_playlist_treeview (GtkBuilder *builder)
 
         popup = GTK_WIDGET (gtk_builder_get_object (builder, "playlist-popup"));
         g_assert (popup != NULL);
+        gtk_menu_attach_to_widget (GTK_MENU (popup), treeview, NULL);
 
-        didl_dialog = GTK_WIDGET (gtk_builder_get_object (builder,
-                                                          "didl-dialog"));
-        g_signal_connect (didl_dialog, "delete-event",
-                          G_CALLBACK (gtk_widget_hide_on_delete), NULL);
-
-        didl_textview = GTK_WIDGET (gtk_builder_get_object (builder,
-                                                          "didl-textview"));
-#ifdef HAVE_GTK_SOURCEVIEW
-        {
-                GtkSourceLanguageManager *manager =
-                                gtk_source_language_manager_get_default ();
-                GtkSourceLanguage *language =
-                    gtk_source_language_manager_guess_language (manager,
-                                                                NULL,
-                                                                "text/xml");
-
-                GtkSourceBuffer *buffer = gtk_source_buffer_new_with_language (language);
-                gtk_source_buffer_set_highlight_syntax (buffer, TRUE);
-                gtk_source_view_set_show_line_numbers (GTK_SOURCE_VIEW (didl_textview),
-                                                       TRUE);
-
-                gtk_text_view_set_buffer (GTK_TEXT_VIEW (didl_textview),
-                                          GTK_TEXT_BUFFER (buffer));
-        }
-#endif
-
+        didl_dialog = GTK_WIDGET (av_cp_didl_dialog_new ());
         expanded = FALSE;
 }
 
@@ -686,6 +692,9 @@ update_device_icon (GUPnPDeviceInfo *info)
         server = AV_CP_MEDIA_SERVER (info);
         g_object_get (G_OBJECT (server), "icon", &icon, NULL);
 
+        if (icon == NULL)
+                return;
+
         if (find_row (model,
                       NULL,
                       &iter,
