@@ -99,11 +99,11 @@ got_icon_url (SoupSession    *session,
               SoupMessage    *msg,
               GetIconURLData *data)
 {
+        GdkPixbuf *pixbuf = NULL;
+
         if (SOUP_STATUS_IS_SUCCESSFUL (msg->status_code)) {
-                GdkPixbuf *pixbuf;
-                GError    *error;
+                GError *error = NULL;
 
-                error = NULL;
                 pixbuf = get_icon_from_message (msg, data, &error);
 
                 if (error) {
@@ -111,18 +111,30 @@ got_icon_url (SoupSession    *session,
                                    gupnp_device_info_get_udn (data->info),
                                    error->message);
                         g_error_free (error);
-                } else if (pixbuf) {
-                        data->callback (data->info, pixbuf);
-                } else {
+                } else if (!pixbuf) {
                         g_warning ("Failed to create icon for '%s'",
                                    gupnp_device_info_get_udn (data->info));
                 }
         }
 
+        data->callback (data->info, pixbuf);
+
         pending_gets = g_list_remove (pending_gets, data);
         get_icon_url_data_free (data);
 }
 
+static gboolean
+on_icon_schedule_error (gpointer user_data)
+{
+        GetIconURLData *data = (GetIconURLData *) user_data;
+
+        data->callback (data->info, NULL);
+        g_object_unref (data->info);
+        g_slice_free (GetIconURLData, data);
+
+        return FALSE;
+}
+
 void
 schedule_icon_update (GUPnPDeviceInfo            *info,
                       DeviceIconAvailableCallback callback)
@@ -130,7 +142,9 @@ schedule_icon_update (GUPnPDeviceInfo            *info,
         GetIconURLData *data;
         char           *icon_url;
 
-        data = g_slice_new (GetIconURLData);
+        data = g_slice_new0 (GetIconURLData);
+        data->info = g_object_ref (info);
+        data->callback = callback;
 
         icon_url = gupnp_device_info_get_icon_url
                         (info,
@@ -143,8 +157,12 @@ schedule_icon_update (GUPnPDeviceInfo            *info,
                          NULL,
                          &data->width,
                          &data->height);
-        if (icon_url == NULL)
+        if (icon_url == NULL) {
+                g_free (data->mime_type);
+
+                g_idle_add (on_icon_schedule_error, data);
                 return;
+        }
 
         data->message = soup_message_new (SOUP_METHOD_GET, icon_url);
 
@@ -155,14 +173,11 @@ schedule_icon_update (GUPnPDeviceInfo            *info,
 
                 g_free (icon_url);
                 g_free (data->mime_type);
-                g_slice_free (GetIconURLData, data);
+                g_idle_add (on_icon_schedule_error, data);
 
                 return;
         }
 
-        data->info = g_object_ref (info);
-        data->callback = callback;
-
         pending_gets = g_list_prepend (pending_gets, data);
         soup_session_queue_message (download_session,
                                     data->message,
@@ -248,16 +263,19 @@ load_pixbuf_file (const char *file_name)
         GdkPixbuf *pixbuf;
         char *path;
 
-        path = g_build_filename (DATA_DIR, file_name, NULL);
-        pixbuf = gdk_pixbuf_new_from_file (path, NULL);
+        path = g_build_path ("/", "/org/gupnp/Tools/Common", file_name, NULL);
+        pixbuf = gdk_pixbuf_new_from_resource (path, NULL);
         if (pixbuf == NULL)
-                g_critical ("failed to get image %s\n", file_name);
+                g_critical ("failed to get image %s\n", path);
 
         g_free (path);
 
         return pixbuf;
 }
 
+extern void gupnp_tools_common_unregister_resource (void);
+extern void gupnp_tools_common_register_resource (void);
+
 void
 init_icons (void)
 {
@@ -277,14 +295,13 @@ init_icons (void)
                 "system-run",                  /* ICON_ACTION     */
                 "folder",                      /* ICON_VARIABLES  */
                 "text-x-generic",              /* ICON_FILE       */
-                "audio-volume-muted",          /* ICON_MIN_VOLUME */
-                "audio-volume-high",           /* ICON_MAX_VOLUME */
                 "folder-remote",               /* ICON_CONTAINER  */
                 "audio-x-generic",             /* ICON_AUDIO_ITEM */
                 "video-x-generic",             /* ICON_VIDEO_ITEM */
                 "image-x-generic",             /* ICON_IMAGE_ITEM */
                 "text-x-generic",              /* ICON_TEXT_ITEM */
         };
+        gupnp_tools_common_register_resource ();
 
         for (i = 0; i < ICON_MISSING; i++) {
                 icons[i] = load_pixbuf_file (file_names[i]);
@@ -321,5 +338,6 @@ deinit_icons (void)
         for (i = 0; i < ICON_LAST; i++) {
                 g_object_unref (icons[i]);
         }
+        gupnp_tools_common_unregister_resource ();
 }
 
