@@ -74,6 +74,9 @@ on_details_treeview_button_release (GtkWidget      *widget,
                       get_selected_row (NULL),
                       NULL);
 
+#if GTK_CHECK_VERSION(3,22,0)
+        gtk_menu_popup_at_pointer (GTK_MENU (popup), (GdkEvent *)event);
+#else
         gtk_menu_popup (GTK_MENU (popup),
                         NULL,
                         NULL,
@@ -81,6 +84,7 @@ on_details_treeview_button_release (GtkWidget      *widget,
                         NULL,
                         event->button,
                         event->time);
+#endif
         return TRUE;
 }
 
